@@ -16,7 +16,7 @@ class JSONLogFormatter(BaseFormatter):
         json_log_fields = BaseJsonLogSchema(
             thread=record.process,
             timestamp=now,
-            level=record.levelno,
+            level=record.levelname,
         )
 
         for key in get_env_extra().keys():
